@@ -1,5 +1,5 @@
 /*
-	$Id: dbdimp.h,v 1.37 2005/05/14 03:02:38 turnstep Exp $
+	$Id: dbdimp.h,v 1.41 2005/06/20 00:36:29 turnstep Exp $
 	
 	Copyright (c) 2000-2005 PostgreSQL Global Development Group
 	Portions Copyright (c) 1997-2000 Edmund Mergl
@@ -11,14 +11,6 @@
 
 #include "types.h"
 
-#ifdef WIN32
-#define snprintf _snprintf
-#endif
-
-#define sword  signed int
-#define sb2    signed short
-#define ub2    unsigned short
-
 /* Define drh implementor data structure */
 struct imp_drh_st {
 	dbih_drc_t com; /* MUST be first element in structure */
@@ -37,8 +29,8 @@ struct imp_dbh_st {
 	int     pg_server_version; /* Server version e.g. 80100 */
 	int     prepare_number;    /* internal prepared statement name modifier */
 	int     copystate;         /* 0=none PGRES_COPY_IN PGRES_COPY_OUT */
-	char    pg_errorlevel;     /* PQsetErrorVerbosity. Set by user, defaults to 1 */
-	char    server_prepare;    /* do we want to use PQexecPrepared? 0=no 1=yes 2=smart. Can be changed by user */
+	int     pg_errorlevel;     /* PQsetErrorVerbosity. Set by user, defaults to 1 */
+	int     server_prepare;    /* do we want to use PQexecPrepared? 0=no 1=yes 2=smart. Can be changed by user */
 
 	AV      *savepoints;       /* list of savepoints */
 	PGconn  *conn;             /* connection structure */
@@ -79,11 +71,10 @@ struct imp_sth_st {
 	bool   is_dml;           /* is this SELECT/INSERT/UPDATE/DELETE? */
 	bool   has_binary;       /* does it have one or more binary placeholders? */
 
-	char   server_prepare;   /* inherited from dbh. 3 states: 0=no 1=yes 2=smart */
-	char   placeholder_type; /* which style is being used 1=? 2=$1 3=:foo */
-
 	STRLEN totalsize;        /* total string length of the statement (with no placeholders)*/
 
+	int    server_prepare;   /* inherited from dbh. 3 states: 0=no 1=yes 2=smart */
+	int    placeholder_type; /* which style is being used 1=? 2=$1 3=:foo */
 	int    numsegs;          /* how many segments this statement has */
 	int    numphs;           /* how many placeholders this statement has */
 	int    numbound;         /* how many placeholders were explicitly bound by the client, not us */
@@ -101,31 +92,32 @@ struct imp_sth_st {
 	ph_t   *ph;              /* linked list of placeholders */
 };
 
-/* Other functions we have added to dbdimp.c */
+/* Other (non-static) functions we have added to dbdimp.c */
 
+int dbd_db_ping(SV *dbh);
+int dbd_db_getfd (SV *dbh, imp_dbh_t *imp_dbh);
 SV * dbd_db_pg_notifies (SV *dbh, imp_dbh_t *imp_dbh);
-int dbd_db_ping ();
-int dbd_db_getfd ();
-int pg_db_putline ();
-int pg_db_getline ();
-int pg_db_endcopy ();
-int pg_db_savepoint ();
-int pg_db_rollback_to ();
-int pg_db_release ();
-void pg_db_pg_server_trace ();
-void pg_db_pg_server_untrace ();
-void pg_db_server_trace ();
-void pg_db_no_server_trace ();
-
-int pg_db_lo_open ();
-int pg_db_lo_close ();
-int pg_db_lo_read ();
-int pg_db_lo_write ();
-int pg_db_lo_lseek ();
-unsigned int pg_db_lo_creat ();
-int pg_db_lo_tell ();
-int pg_db_lo_unlink ();
-unsigned int pg_db_lo_import ();
-int pg_db_lo_export ();
+int pg_db_putline (SV *dbh, const char *buffer);
+int pg_db_getline (SV *dbh, char *buffer, int length);
+int pg_db_endcopy (SV * dbh);
+void pg_db_pg_server_trace (SV *dbh, FILE *fh);
+void pg_db_pg_server_untrace (SV *dbh);
+int pg_db_savepoint (SV *dbh, imp_dbh_t *imp_dbh, char * savepoint);
+int pg_db_rollback_to (SV *dbh, imp_dbh_t *imp_dbh, char * savepoint);
+int pg_db_release (SV *dbh, imp_dbh_t *imp_dbh, char * savepoint);
+unsigned int pg_db_lo_creat (SV *dbh, int mode);
+int pg_db_lo_open (SV *dbh, unsigned int lobjId, int mode);
+int pg_db_lo_close (SV *dbh, int fd);
+int pg_db_lo_read (SV *dbh, int fd, char *buf, size_t len);
+int pg_db_lo_write (SV *dbh, int fd, char *buf, size_t len);
+int pg_db_lo_lseek (SV *dbh, int fd, int offset, int whence);
+int pg_db_lo_tell (SV *dbh, int fd);
+int pg_db_lo_unlink (SV *dbh, unsigned int lobjId);
+unsigned int pg_db_lo_import (SV *dbh, char *filename);
+int pg_db_lo_export (SV *dbh, unsigned int lobjId, char *filename);
 
 /* end of dbdimp.h */
+
+
+
+
